#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef PACKAGE
#undef VERSION
#undef GLADE_DEBUG
#undef GLADE_LOCALE_DIR
#undef GLADE_DATA_DIR
#undef USE_GNOME
#undef PALETTE_TYPE
